@@ -35,6 +35,11 @@ class AppTool(object):
         self.init_logger()
 
 
+    @property
+    def name(self):
+        return self._app_name
+
+
     @property
     def config(self):
         return self._config
